summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2003-01-24 08:08:45 +0000
committerJohnny Willemsen <jwillemsen@remedy.nl>2003-01-24 08:08:45 +0000
commit484eee53a656620726e762a9aa3dc32b292ba54e (patch)
treef42121cd308e0a37b6f4cea7a1ddf74ad1b520f5
parent814a649fc10af56263b10b2f14cb1f5660517bfa (diff)
downloadATCD-484eee53a656620726e762a9aa3dc32b292ba54e.tar.gz
ChangeLogTag: Fri Jan 24 08:04:12 UTC 2002 Johnny Willemsen <jwillemsen@remedy.nl>
-rw-r--r--TAO/orbsvcs/PSS/Makefile11
-rw-r--r--TAO/orbsvcs/PSS/Makefile.datastore11
-rw-r--r--TAO/orbsvcs/orbsvcs/AV/MCast.cpp6
-rw-r--r--TAO/orbsvcs/orbsvcs/AV/RTP.cpp2
-rw-r--r--TAO/orbsvcs/orbsvcs/AV/TCP.cpp6
-rw-r--r--TAO/orbsvcs/orbsvcs/AV/UDP.cpp8
-rw-r--r--TAO/orbsvcs/orbsvcs/ESF/ESF_Worker.h2
-rw-r--r--TAO/orbsvcs/orbsvcs/Event/ECG_UDP_Sender.cpp4
-rw-r--r--TAO/orbsvcs/orbsvcs/Makefile.DsEventLogAdmin13
-rw-r--r--TAO/orbsvcs/orbsvcs/Makefile.DsLogAdmin13
-rw-r--r--TAO/orbsvcs/orbsvcs/Makefile.DsNotifyLogAdmin13
-rw-r--r--TAO/orbsvcs/orbsvcs/Makefile.RTEventLogAdmin13
12 files changed, 84 insertions, 18 deletions
diff --git a/TAO/orbsvcs/PSS/Makefile b/TAO/orbsvcs/PSS/Makefile
index 1279905d423..d447d7017c5 100644
--- a/TAO/orbsvcs/PSS/Makefile
+++ b/TAO/orbsvcs/PSS/Makefile
@@ -78,6 +78,17 @@ include $(ACE_ROOT)/include/makeinclude/rules.local.GNU
LDFLAGS += -L$(TAO_ROOT)/tao
CPPFLAGS += -I$(TAO_ROOT)
+ifeq ($(shared_libs),1)
+ifneq ($(SHLIB),)
+CPPFLAGS += -DTAO_PSDL_BUILD_DLL
+endif
+endif
+ifeq ($(static_libs),1)
+ifneq ($(LIB),)
+CPPFLAGS += -DTAO_AS_STATIC_LIBS -DACE_AS_STATIC_LIBS
+endif
+endif
+
# Extra dependencies not caught by make depend.
MKLIST = Makefile.datastore Makefile.parser
diff --git a/TAO/orbsvcs/PSS/Makefile.datastore b/TAO/orbsvcs/PSS/Makefile.datastore
index b1cedba186a..81ab2b66d65 100644
--- a/TAO/orbsvcs/PSS/Makefile.datastore
+++ b/TAO/orbsvcs/PSS/Makefile.datastore
@@ -52,6 +52,17 @@ CPPFLAGS += -I$(TAO_ROOT) -I$(TAO_ROOT)/orbsvcs \
-I$(TAO_ROOT)/orbsvcs/PSS \
$(foreach svc, $(TAO_ORBSVCS), -DTAO_ORBSVCS_HAS_$(svc))
+ifeq ($(shared_libs),1)
+ifneq ($(SHLIB),)
+CPPFLAGS += -DTAO_PSDL_BUILD_DLL
+endif
+endif
+ifeq ($(static_libs),1)
+ifneq ($(LIB),)
+CPPFLAGS += -DTAO_AS_STATIC_LIBS -DACE_AS_STATIC_LIBS
+endif
+endif
+
# Extra dependencies not caught by make depend.
.PRECIOUS: $(foreach file, $(IDL_FILES), $(foreach ext, $(IDL_EXT), $(file)$(ext))))
diff --git a/TAO/orbsvcs/orbsvcs/AV/RTP.cpp b/TAO/orbsvcs/orbsvcs/AV/RTP.cpp
index 4736e8bbd5c..809fe8d4a7e 100644
--- a/TAO/orbsvcs/orbsvcs/AV/RTP.cpp
+++ b/TAO/orbsvcs/orbsvcs/AV/RTP.cpp
@@ -587,7 +587,7 @@ TAO_AV_RTP_Object::send_frame (const iovec *iov,
ACE_UINT16 data_length;
rtp_packet->get_packet_data (&data_ptr, data_length);
- iovec send_iov[IOV_MAX];
+ iovec send_iov[ACE_IOV_MAX];
send_iov [0].iov_base = data_ptr;
send_iov [0].iov_len = data_length;
for (int i=1;i<iovcnt; i++)
diff --git a/TAO/orbsvcs/orbsvcs/ESF/ESF_Worker.h b/TAO/orbsvcs/orbsvcs/ESF/ESF_Worker.h
index fe282efe565..dcdd83568c7 100644
--- a/TAO/orbsvcs/orbsvcs/ESF/ESF_Worker.h
+++ b/TAO/orbsvcs/orbsvcs/ESF/ESF_Worker.h
@@ -22,7 +22,7 @@
/**
* The Event Service Framework uses Worker classes to iterate over
* collections of proxies.
- * The followin class defines the worker interface, basically users of
+ * The following class defines the worker interface, basically users of
* the framework implement a worker object and pass it to one
* collection. The collection invokes the worker for each element the
* colection contains.
diff --git a/TAO/orbsvcs/orbsvcs/Event/ECG_UDP_Sender.cpp b/TAO/orbsvcs/orbsvcs/Event/ECG_UDP_Sender.cpp
index eac9230d22c..bae643dcd04 100644
--- a/TAO/orbsvcs/orbsvcs/Event/ECG_UDP_Sender.cpp
+++ b/TAO/orbsvcs/orbsvcs/Event/ECG_UDP_Sender.cpp
@@ -313,9 +313,9 @@ TAO_ECG_UDP_Sender::send_cdr_stream (const RtecUDPAdmin::UDP_Addr& udp_addr,
// ACE_ASSERT (max_fragment_payload != 0);
#if defined (ACE_HAS_BROKEN_DGRAM_SENDV)
- const int TAO_WRITEV_MAX = IOV_MAX - 1;
+ const int TAO_WRITEV_MAX = ACE_IOV_MAX - 1;
#else
- const int TAO_WRITEV_MAX = IOV_MAX;
+ const int TAO_WRITEV_MAX = ACE_IOV_MAX;
#endif /* ACE_HAS_BROKEN_DGRAM_SENDV */
iovec iov[TAO_WRITEV_MAX];
diff --git a/TAO/orbsvcs/orbsvcs/Makefile.DsEventLogAdmin b/TAO/orbsvcs/orbsvcs/Makefile.DsEventLogAdmin
index 48d6f84e0b0..f15e03a75bc 100644
--- a/TAO/orbsvcs/orbsvcs/Makefile.DsEventLogAdmin
+++ b/TAO/orbsvcs/orbsvcs/Makefile.DsEventLogAdmin
@@ -37,7 +37,7 @@ CPP_SRCS += \
Log/EventLogFactory_i \
Log/EventLog_i \
Log/EventLogConsumer \
- Log/EventLogNotification
+ Log/EventLogNotification
IDL_SRC = \
$(addsuffix S.cpp, $(IDL_FILES)) \
@@ -60,6 +60,17 @@ include $(ACE_ROOT)/include/makeinclude/rules.local.GNU
LDFLAGS += -L$(TAO_ROOT)/tao -L$(TAO_ROOT)/orbsvcs/orbsvcs
CPPFLAGS += -I$(TAO_ROOT) -I$(TAO_ROOT)/orbsvcs
+ifeq ($(shared_libs),1)
+ifneq ($(SHLIB),)
+CPPFLAGS += -DTAO_EVENTLOG_BUILD_DLL
+endif
+endif
+ifeq ($(static_libs),1)
+ifneq ($(LIB),)
+CPPFLAGS += -DTAO_AS_STATIC_LIBS -DACE_AS_STATIC_LIBS
+endif
+endif
+
.PRECIOUS: $(foreach file, $(IDL_FILES), $(foreach ext, $(IDL_EXT), $(file)$(ext))))
realclean: clean
diff --git a/TAO/orbsvcs/orbsvcs/Makefile.DsLogAdmin b/TAO/orbsvcs/orbsvcs/Makefile.DsLogAdmin
index 1530c02ce9a..b3180c08730 100644
--- a/TAO/orbsvcs/orbsvcs/Makefile.DsLogAdmin
+++ b/TAO/orbsvcs/orbsvcs/Makefile.DsLogAdmin
@@ -43,7 +43,7 @@ CPP_SRCS += \
Log/LogMgr_i \
Log/Log_Constraint_Visitors \
Log/Log_Constraint_Interpreter \
- Log/LogNotification
+ Log/LogNotification
IDL_SRC = \
$(addsuffix S.cpp, $(IDL_FILES)) \
@@ -66,6 +66,17 @@ include $(ACE_ROOT)/include/makeinclude/rules.local.GNU
LDFLAGS += -L$(TAO_ROOT)/tao -L$(TAO_ROOT)/orbsvcs/orbsvcs
CPPFLAGS += -I$(TAO_ROOT) -I$(TAO_ROOT)/orbsvcs
+ifeq ($(shared_libs),1)
+ifneq ($(SHLIB),)
+CPPFLAGS += -DTAO_LOG_BUILD_DLL
+endif
+endif
+ifeq ($(static_libs),1)
+ifneq ($(LIB),)
+CPPFLAGS += -DTAO_AS_STATIC_LIBS -DACE_AS_STATIC_LIBS
+endif
+endif
+
.PRECIOUS: $(foreach file, $(IDL_FILES), $(foreach ext, $(IDL_EXT), $(file)$(ext))))
realclean: clean
diff --git a/TAO/orbsvcs/orbsvcs/Makefile.DsNotifyLogAdmin b/TAO/orbsvcs/orbsvcs/Makefile.DsNotifyLogAdmin
index 009ae620880..bffe5a638ec 100644
--- a/TAO/orbsvcs/orbsvcs/Makefile.DsNotifyLogAdmin
+++ b/TAO/orbsvcs/orbsvcs/Makefile.DsNotifyLogAdmin
@@ -37,7 +37,7 @@ CPP_SRCS += \
Log/NotifyLogFactory_i \
Log/NotifyLog_i \
Log/NotifyLogConsumer \
- Log/NotifyLogNotification
+ Log/NotifyLogNotification
IDL_SRC = \
$(addsuffix S.cpp, $(IDL_FILES)) \
@@ -60,6 +60,17 @@ include $(ACE_ROOT)/include/makeinclude/rules.local.GNU
LDFLAGS += -L$(TAO_ROOT)/tao -L$(TAO_ROOT)/orbsvcs/orbsvcs
CPPFLAGS += -I$(TAO_ROOT) -I$(TAO_ROOT)/orbsvcs
+ifeq ($(shared_libs),1)
+ifneq ($(SHLIB),)
+CPPFLAGS += -DTAO_LOG_BUILD_DLL
+endif
+endif
+ifeq ($(static_libs),1)
+ifneq ($(LIB),)
+CPPFLAGS += -DTAO_AS_STATIC_LIBS -DACE_AS_STATIC_LIBS
+endif
+endif
+
.PRECIOUS: $(foreach file, $(IDL_FILES), $(foreach ext, $(IDL_EXT), $(file)$(ext))))
realclean: clean
diff --git a/TAO/orbsvcs/orbsvcs/Makefile.RTEventLogAdmin b/TAO/orbsvcs/orbsvcs/Makefile.RTEventLogAdmin
index 619836336a0..65367299564 100644
--- a/TAO/orbsvcs/orbsvcs/Makefile.RTEventLogAdmin
+++ b/TAO/orbsvcs/orbsvcs/Makefile.RTEventLogAdmin
@@ -37,7 +37,7 @@ CPP_SRCS += \
Log/RTEventLogFactory_i \
Log/RTEventLog_i \
Log/RTEventLogConsumer \
- Log/RTEventLogNotification
+ Log/RTEventLogNotification
IDL_SRC = \
$(addsuffix S.cpp, $(IDL_FILES)) \
@@ -60,6 +60,17 @@ include $(ACE_ROOT)/include/makeinclude/rules.local.GNU
LDFLAGS += -L$(TAO_ROOT)/tao -L$(TAO_ROOT)/orbsvcs/orbsvcs
CPPFLAGS += -I$(TAO_ROOT) -I$(TAO_ROOT)/orbsvcs
+ifeq ($(shared_libs),1)
+ifneq ($(SHLIB),)
+CPPFLAGS += -DTAO_RTEVENTLOG_BUILD_DLL
+endif
+endif
+ifeq ($(static_libs),1)
+ifneq ($(LIB),)
+CPPFLAGS += -DTAO_AS_STATIC_LIBS -DACE_AS_STATIC_LIBS
+endif
+endif
+
.PRECIOUS: $(foreach file, $(IDL_FILES), $(foreach ext, $(IDL_EXT), $(file)$(ext))))
realclean: clean
diff --git a/TAO/orbsvcs/orbsvcs/AV/MCast.cpp b/TAO/orbsvcs/orbsvcs/AV/MCast.cpp
index f6a6ab6a4dd..9654e72fd4c 100644
--- a/TAO/orbsvcs/orbsvcs/AV/MCast.cpp
+++ b/TAO/orbsvcs/orbsvcs/AV/MCast.cpp
@@ -105,7 +105,7 @@ TAO_AV_UDP_MCast_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value
// For the most part this was copied from GIOP::send_request and
// friends.
- iovec iov[IOV_MAX];
+ iovec iov[ACE_IOV_MAX];
int iovcnt = 0;
ssize_t n = 0;
ssize_t nbytes = 0;
@@ -126,8 +126,8 @@ TAO_AV_UDP_MCast_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value
// platforms do not implement writev() there we should copy
// the data into a buffer and call send_n(). In other cases
// there may be some limits on the size of the iovec, there
- // we should set IOV_MAX to that limit.
- if (iovcnt == IOV_MAX)
+ // we should set ACE_IOV_MAX to that limit.
+ if (iovcnt == ACE_IOV_MAX)
{
n = this->handler_->get_mcast_socket ()->send ((const iovec *) iov,
iovcnt);
diff --git a/TAO/orbsvcs/orbsvcs/AV/TCP.cpp b/TAO/orbsvcs/orbsvcs/AV/TCP.cpp
index 61aca7eea37..f61bcb22330 100644
--- a/TAO/orbsvcs/orbsvcs/AV/TCP.cpp
+++ b/TAO/orbsvcs/orbsvcs/AV/TCP.cpp
@@ -53,7 +53,7 @@ TAO_AV_TCP_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value *)
// For the most part this was copied from GIOP::send_request and
// friends.
- iovec iov[IOV_MAX];
+ iovec iov[ACE_IOV_MAX];
int iovcnt = 0;
ssize_t n = 0;
ssize_t nbytes = 0;
@@ -74,8 +74,8 @@ TAO_AV_TCP_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value *)
// platforms do not implement writev() there we should copy
// the data into a buffer and call send_n(). In other cases
// there may be some limits on the size of the iovec, there
- // we should set IOV_MAX to that limit.
- if (iovcnt == IOV_MAX)
+ // we should set ACE_IOV_MAX to that limit.
+ if (iovcnt == ACE_IOV_MAX)
{
n = this->handler_->peer ().sendv_n ((const iovec *) iov,
iovcnt);
diff --git a/TAO/orbsvcs/orbsvcs/AV/UDP.cpp b/TAO/orbsvcs/orbsvcs/AV/UDP.cpp
index 3c1e1f8c992..4e3b627591b 100644
--- a/TAO/orbsvcs/orbsvcs/AV/UDP.cpp
+++ b/TAO/orbsvcs/orbsvcs/AV/UDP.cpp
@@ -206,7 +206,7 @@ TAO_AV_UDP_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value *)
// For the most part this was copied from GIOP::send_request and
// friends.
- iovec iov[IOV_MAX];
+ iovec iov[ACE_IOV_MAX];
int iovcnt = 0;
ssize_t n = 0;
ssize_t nbytes = 0;
@@ -227,8 +227,8 @@ TAO_AV_UDP_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value *)
// platforms do not implement writev() there we should copy
// the data into a buffer and call send_n(). In other cases
// there may be some limits on the size of the iovec, there
- // we should set IOV_MAX to that limit.
- if (iovcnt == IOV_MAX)
+ // we should set ACE_IOV_MAX to that limit.
+ if (iovcnt == ACE_IOV_MAX)
{
n = this->handler_->get_socket ()->send ((const iovec *) iov,
iovcnt,
@@ -327,7 +327,7 @@ TAO_AV_UDP_Acceptor::~TAO_AV_UDP_Acceptor (void)
{
if (this->flow_component_ == TAO_AV_Core::TAO_AV_CONTROL)
delete this->entry_->control_handler ();
-
+
delete this->address_;
delete this->control_inet_address_;
}